pub struct AddressInitialKey { /* private fields */ }Expand description
Blocks on: (first token of address field) + “:” + (first char of first-name field). Handles surname transpositions, two records at the same address with the same initial should end up in the same bucket even if the surname differs.
Implementations