AddressInitialKey

Struct AddressInitialKey 

pub struct AddressInitialKey { /* private fields */ }
Blocks on: (first token of address field) + “:” + (first char of first-name field). Handles surname transpositions, two records at the same address with the same initial should end up in the same bucket even if the surname differs.

Implementations

Source

impl AddressInitialKey

pub fn new(address_field: &str, first_name_field: &str) -> Self